Demo
====

.. automodule:: frappy_demo.cryo
    :show-inheritance:
    :members:

.. automodule:: frappy_demo.test
    :show-inheritance:
    :members:

.. automodule:: frappy_demo.lakeshore
    :show-inheritance:
    :members:
